@@ -1,10 +1,10 @@
-# Copyright (c) 2010-2023 openpyxl
+# Copyright (c) 2010-2024 openpyxl
 
 
 def test_color_descriptor():
     from ..colors import ColorChoiceDescriptor
 
-    class DummyStyle(object):
+    class DummyStyle:
 
         value = ColorChoiceDescriptor('value')
 
