@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2023 openpyxl
+# Copyright (c) 2010-2024 openpyxl
 
 # test imports
 import pytest
@@ -454,6 +454,15 @@ class TestWorksheet:
         assert len(tbl_ws._tables) == 1
 
 
+    def test_column_groups(self, Worksheet):
+        ws = Worksheet(Workbook())
+        ws.column_dimensions["A"]
+        ws.column_dimensions["F"]
+        ws.column_dimensions.group("F", "K")
+
+        assert ws.column_groups == ["F:K"]
+
+
 def test_freeze_panes_horiz(Worksheet):
     ws = Worksheet(Workbook())
     ws.freeze_panes = 'A4'
